==> jasperreports_3.7.0+dfsg.orig.tar.gz: jasperreports-3.7.0.orig/src/net/sf/jasperreports/engine/xml/JROriginFactory.java <==
/*
 * JasperReports - Free Java Reporting Library.
 * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
 * http://www.jaspersoft.com
 *
 * Unless you have purchased a commercial license agreement from Jaspersoft,
 * the following license terms apply:
 *
 * This program is part of JasperReports.
 *
 * JasperReports is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * JasperReports is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
 */
package net.sf.jasperreports.engine.xml;

import net.sf.jasperreports.engine.JROrigin;

import org.xml.sax.Attributes;


/**
 * @author Teodor Danciu (teodord@users.sourceforge.net)
 * @version $Id: JROriginFactory.java 3034 2009-08-27 11:58:04Z teodord $
 */
public class JROriginFactory extends JRBaseFactory
{
	

	/**
	 *
	 */
	public Object createObject(Attributes atts)
	{
		return 
			new JROrigin(
				atts.getValue(JRXmlConstants.ATTRIBUTE_report),
				atts.getValue(JRXmlConstants.ATTRIBUTE_group),
				((Byte)JRXmlConstants.getBandTypeMap().get(atts.getValue(JRXmlConstants.ATTRIBUTE_band))).byteValue()
				);
	}
	

}

==> jasperreports_3.7.4+dfsg.orig.tar.gz: jasperreports-3.7.4.orig/src/net/sf/jasperreports/engine/xml/JROriginFactory.java <==
/*
 * JasperReports - Free Java Reporting Library.
 * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
 * http://www.jaspersoft.com
 *
 * Unless you have purchased a commercial license agreement from Jaspersoft,
 * the following license terms apply:
 *
 * This program is part of JasperReports.
 *
 * JasperReports is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * JasperReports is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
 */
package net.sf.jasperreports.engine.xml;

import net.sf.jasperreports.engine.JROrigin;
import net.sf.jasperreports.engine.type.BandTypeEnum;

import org.xml.sax.Attributes;


/**
 * @author Teodor Danciu (teodord@users.sourceforge.net)
 * @version $Id: JROriginFactory.java 3616 2010-03-24 14:20:41Z teodord $
 */
public class JROriginFactory extends JRBaseFactory
{
	

	/**
	 *
	 */
	public Object createObject(Attributes atts)
	{
		return 
			new JROrigin(
				atts.getValue(JRXmlConstants.ATTRIBUTE_report),
				atts.getValue(JRXmlConstants.ATTRIBUTE_group),
				BandTypeEnum.getByName(atts.getValue(JRXmlConstants.ATTRIBUTE_band))
				);
	}
	

}
